@@ -18,21 +18,12 @@
 #include <algorithm>
 #include <iostream.h>
 #include <pfstream.h>
-#include <linux/ext2_fs.h>
 #include "vutil.h"
 
-// Patch to help compile this utility on unpatched kernel source
-#ifndef EXT2_IMMUTABLE_FILE_FL
-	#define EXT2_IMMUTABLE_FILE_FL	0x00000010
-	#define EXT2_IMMUTABLE_LINK_FL	0x00008000
-#endif
-
-
 using namespace std;
 
-extern bool testmode;
 static bool undo = false;
-static bool debug = false;
+
 static int  ext2flags = EXT2_IMMUTABLE_FILE_FL | EXT2_IMMUTABLE_LINK_FL;
 struct EXCLDIR{
 	string prefix;
@@ -91,37 +82,21 @@ static bool vunify_inside (vector<EXCLDIR> &dirs, const char *path)
 	return found;
 }
 
-class PACKAGE{
+class PACKAGE_UNI: public PACKAGE{
 public:
-	string name;
-	string version;	// version + release
 	list<string> files;		// Files to unify
 							// This is loaded on demand
-	PACKAGE(string &_name, string &_version)
-		: name (_name), version(_version)
+	PACKAGE_UNI(string &_name, string &_version)
+		: PACKAGE(_name,_version)
 	{
 	}
-	PACKAGE(const char *_name, const char *_version)
-		: name (_name), version(_version)
+	PACKAGE_UNI(const char *_name, const char *_version)
+		: PACKAGE (_name,_version)
 	{
 	}
-	PACKAGE(const string &line)
+	PACKAGE_UNI(const string &line)
+		: PACKAGE (line)
 	{
-		*this = line;
-	}
-	PACKAGE & operator = (const string &_line)
-	{
-		string line (_line);
-		string::iterator pos = find (line.begin(),line.end(),'=');
-		if (pos != line.end()){
-			name = string(line.begin(),pos);
-			version = string(pos + 1,line.end());
-		}
-		return *this;
-	}
-	bool operator == (const PACKAGE &v) const
-	{
-		return name == v.name && version == v.version;
 	}
 	// Load the file member of the package, but exclude configuration file
 	void loadfiles(const string &ref)
@@ -169,7 +144,7 @@ public:
 };
 
 
-static ostream & operator << (ostream &c, const PACKAGE &p)
+static ostream & operator << (ostream &c, const PACKAGE_UNI &p)
 {
 	return c << p.name << "-" << p.version;
 }
@@ -193,7 +168,7 @@ template<class T>
 /*
 	Load the list of all packages in a vserver
 */
-static void vunify_loadallpkg (string &refserver, list<PACKAGE> &packages)
+static void vunify_loadallpkg (string &refserver, list<PACKAGE_UNI> &packages)
 {
 	string cmd = "| /usr/sbin/chroot /vservers/" + refserver + " /bin/rpm -qa"
 		+ " --queryformat \"%{name}=%{version}-%{release}\\n\"";
@@ -253,10 +228,10 @@ class file_unifier{
 };
 // CHeck if two package have the same name (but potentially different version)
 class same_name{
-	PACKAGE &pkg;
+	PACKAGE_UNI &pkg;
 public:
-	same_name(PACKAGE &_pkg) : pkg(_pkg) {}
-	bool operator()(const PACKAGE &p)
+	same_name(PACKAGE_UNI &_pkg) : pkg(_pkg) {}
+	bool operator()(const PACKAGE_UNI &p)
 	{
 		return pkg.name == p.name;
 	}
@@ -265,16 +240,16 @@ public:
 class package_unifier{
 public:
 	string &ref_server,&target_server;
-	list<PACKAGE> &target_packages;
+	list<PACKAGE_UNI> &target_packages;
 	int &ret;
 	package_unifier(string &_ref,
 			string &_target,
-			list<PACKAGE> &_target_packages,
+			list<PACKAGE_UNI> &_target_packages,
 			int &_ret)
 		: ref_server(_ref),target_server(_target)
 		, target_packages(_target_packages) , ret(_ret)
 	{}
-	void operator()(PACKAGE &pkg)
+	void operator()(PACKAGE_UNI &pkg)
 	{
 		if (find(target_packages.begin(),target_packages.end(),pkg)
 			!=target_packages.end()){
@@ -302,15 +277,15 @@ public:
 // For each vserver, find the common packages and unify them
 class server_unifier{
 public:
-	list<PACKAGE> &ref_packages;
+	list<PACKAGE_UNI> &ref_packages;
 	string &ref_server;
 	int &ret;
-	server_unifier(string _ref_server, list<PACKAGE> &_packages, int &_ret)
+	server_unifier(string _ref_server, list<PACKAGE_UNI> &_packages, int &_ret)
 		: ref_packages(_packages),ref_server(_ref_server), ret(_ret)
 		{}
 	void operator()(string serv)
 	{
-		list<PACKAGE> pkgs;
+		list<PACKAGE_UNI> pkgs;
 		vunify_loadallpkg (serv,pkgs);
 		for_each(ref_packages.begin(),ref_packages.end()
 			,package_unifier(ref_server,serv,pkgs,ret));
@@ -320,7 +295,7 @@ class deleteif{
 public:
 	char **argv0,**argvn;
 	deleteif(char **_argv0, char **_argvn): argv0(_argv0),argvn(_argvn){}
-	bool operator()(const PACKAGE &pkg)
+	bool operator()(const PACKAGE_UNI &pkg)
 	{
 		bool found = false;
 		for (char **pt = argv0; pt < argvn; pt++){
@@ -345,7 +320,7 @@ int main (int argc, char *argv[])
 		}else if (strcmp(arg,"--undo")==0){
 			undo = true;
 		}else if (strcmp(arg,"--debug")==0){
-			debug = true;
+			debug++;
 		}else if (strcmp(arg,"--noflags")==0){
 			ext2flags = 0;
 		}else if (strcmp(arg,"--immutable")==0){
@@ -377,7 +352,7 @@ int main (int argc, char *argv[])
 		}else{
 			i++;
 			if (i < argc){
-				list<PACKAGE> packages;
+				list<PACKAGE_UNI> packages;
 				vunify_loadallpkg (refserv,packages);
 				if (i != argc-1 || strcmp(argv[i],"ALL")!=0){
 					// We keep only the packages supplied on the command line
